/**
 * Image capable of preloading into an invisible element.
 * @param {string} id A unique identifier for the preloading image.
 * @param {string} url URL to the image resource.
 */
function PreloadingImage(id, url) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;

    var invisibleClass = "invisible";

    var promiseResolve;
    var promiseReject;
    var promise = new Promise(function (resolve, reject) {
        promiseResolve = resolve;
        promiseReject = reject;
    });

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Checks whether or not the image already exists.
     * @returns {boolean} Truthy if the image already exists, false otherwise.
     */
    function exists() {
        return $("#" + id).length;
    }

    /**
     * Checks whether or not the image is currently loading.
     * @returns {boolean} Truthy if the image exists and is already loading, false otherwise.
     */
    function isLoading() {
        return exists() && !$("#" + id)[0].complete;
    }

    /**
     * Adds the image to the DOM, with a registered load listener.
     */
    function addImage() {
        var img = document.createElement("img");
        img.onload = promiseResolve;
        img.className = invisibleClass;
        img.src = url;
        img.id = id;
        $("body").append(img);
    }

    /**
     * Adds the onload listener to an image already loading.
     */
    function addListenerToExistingImage() {
        var img = $("#" + id)[0];
        if (img.onload) {
            var original = img.onload;
            img.onload = function () {
                original();
                promiseResolve();
            };
        } else {
            img.onload = promiseResolve;
        }
    }

    // PUBLIC MEMBERS \\        this.public = "test";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Makes the image load itself if it has not yet loaded.
     * @returns {Promise} A promise which will resolve when the image has finished loading, or immediately if it already has loaded.
     */
    this.preload = function () {
        if (!exists()) {
            addImage();
        } else if (isLoading()) {
            addListenerToExistingImage();
        } else {
            promiseResolve();
        }
        return promise;
    };
}

