/**
 * Result section of Enslavement, Noon Two.
 * @param {SlaveNoonTwoController} controller The Enslavement, Noon Two controller.
 */
function SlaveNoonTwoFarmer(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = SlaveNoonTwoResultsChoice.FARMER;
    var reqController = ctrl.result;
    var changeController = false;

    var nextSceneReady = ctrl.farmerSceneReady;
    var nextSceneName = ctrl.farmerSceneName;
    var nextFolderName = ctrl.farmerFolderName;

    var continueId = arguments.callee.name + "ButtonOne";

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var name = ctrl.misc.name();
        var toReturn = `[p]
                            "[color=orange]One hundred.[/color]" a gentle, feminine voice rings out.
                            It's the half-naked vixen.
                            She's soon challenged by the goblin, whose stingy pockets seem far deeper than what you'd have imagined.
                            "[color=green]One hundred and twenty![/color]"
                            The kind-looking canine casts a wicked leer towards the small humanoid.
                            "[color=orange]One hundred and fifty. Or would you rather deal with a back-handed [b]greenskin[/b]?[/color]"
                            "[color=green][b]One fifty-one[/b]![/color]"
                        [/p]
                        [p]
                            Bartholomew seems conflicted.
                            For a moment, it feels as though a [b]fight[/b] is brewing between the two interested parties.
                            But then, right as temperatures are about to reach a boiling point, a third buyer voices his interest.
                            The human farmer, egged on by his avian son, speaks up in a loud, authorative voice.
                            "[color=red][b]Two hundred gold![/b]![/color]"
                        [/p]
                        [p]
                            You can almost [b]see[/b] the avarice in your slaver's eyes.
                            "[color=brown][b]Sold[/b], to the man who needs a bath![/color]"
                            The goblin grumbles and complains,
                            and the vixen looks dissatisfied with having her purchase snagged out from underneath her,
                            but the farmer's bid is final.
                            The crowd parts and money exchanges hands.
                            Seki must have wandered off somewhere during the bidding.
                            He's nowhere to be seen.
                        [/p]
                        [p]
                            While Barto chats with the family, Fenrir approaches you.
                            "[color=gblue]Well, ${name}, you're theirs now.
                            They look famished.
                            Behave, or they might well end up [b]eating[/b] you.
                            And that kid of theirs...
                            I'm no psychologist, but he looks like he has some [b]issues[/b].
                            Then again, wouldn't you, as an eagle with human parents?
                            Anyway, good luck.
                            You're going to need it.
                            Watch your back, you troublemakin' lil' lizard.[/color]"
                        [/p]
                        [p]
                            Having said his farewells, the big wolf pushes you forwards, nudging you off of the small stage, towards your new [i]family[/i].
                            The deal concluded, your former [i]master[/i] and the lupine walk back to the carriages, bickering on how to split their profits.
                            The farmer kneels down in front of you, coarsely grabbing your jaw, prying your muzzle open, gazing into your maw.
                            "[color=red]Good teeth, those'll sell well.[/color]"
                            [i]Sell well[/i]?
                            You don't like the sound of that.
                            Are they going to [b]eat you[/b], like Fenrir said?!
                            He turns his attention towards the bird.
                            "[color=red]A lot more expensive than a new dog.
                            Remember: this one is our [b]maid[/b].
                            Not your [b]pet[/b].[/color]"
                        [/p]
                        [p]
                            Phew.
                            A [b]maid[/b].
                            Better than a [i]meal[/i].
                            The eagle rolls his eyes.
                            "[color=yellow]Quit treating me like a [b]child[/b].[/color]"
                            His backtalk angers the human.
                            "[color=red]You look like one, and you [b]act[/b] like one.[/color]"
                            Your thoughts exactly.
                            The boy appears to be in his early teens, if not even younger than that.
                            He's about your height, maybe a little bigger.
                            His voice is high-pitched as well.
                        [/p]
                        [p]
                            You think Seki once told you about this [i]trait[/i] that certain breeds of anthro avians have,
                            where they look exceedingly [b]young[/b], until they reach their twenties,
                            when they get a sudden growth spurt, and their bodies change to reflect their adult minds.
                            You wonder if the owl himself went through such a period, but this is neither the time,
                            nor the place to think about such things.
                        [/p]
                        [p]
                            The point of this entire train of thought is that you basically have [b]no way[/b] of knowing how old the eagle really is.
                            He could be anywhere from [b]eight[/b] to [b]twenty[/b] years old.
                            Judging by how he took offense to his [i]father[/i] treating him like a kid,
                            you think he's at least hit [i]hormonal[/i] puberty.
                            But you could be wrong about that.
                            You could be wrong about all of this.
                            Does it even matter?
                        [/p]
                        [p]
                            The farmer rises to his feet, and sends his family back home.
                            You hesitantly ask why [i]you[/i] aren't going [i]with them[/i].
                            "[color=red]We're paying a visit to the [b]workshop[/b] first.[/color]"
                            The [i]workshop[/i]?
                            T-to buy a [b]broom[/b], right?
                            The human doesn't respond.
                            Instead, he shoots you a grimace so serious,
                            it sends chills down your spine.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.continued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueId}" ${disabled ? "disabled" : ""}>`;
        choice += `Continue &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next scene.
     * @param {string} sceneName Name of the scene to load.
     * @param {string} folder Folder of the scene to load.
     */
    function loadNextPart(sceneName, folder) {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(sceneName, folder);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(nextSceneName, nextFolderName);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        if (!nextSceneReady) {
            part += `<span class="todo">There is no content beyond this point.</span>`;
        }
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        if (ctrl.continued()) {
            return;
        }

        if (nextSceneReady) {
            registerContinueListener();
        }
    };
}
