/**
 * The first section of the bandit part of the Forest scene.
 * @param {ForestController} controller The forest controller.
 */
function ForestBanditArrival(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var toReward = new ForestBanditReward(ctrl);
    var toWatch = new ForestBanditWatch(ctrl);
    var toIntervene = new ForestBanditIntervene(ctrl, toReward);
    var toRock = new ForestBanditRock(ctrl, toIntervene, toReward);

    var rockId = "banditRockButton";
    var interveneId = "banditInterveneButton";
    var watchId = "banditWatchButton";

    var contentFromWoods = `<div class="text">
                                You keep moving, yet stick to the woodland regions you're familiar with,
                                which inadvertently leads you just a little bit closer to your own home.
                                If anyone was following you, they've now most likely been thrown off the trail,
                                seeing as your decision lead you to take a sharp turn back towards the eastern road,
                                as opposed to continuing on in a straight line deeper into the woods.
                            </div>
                            <div class="text">
                                You go at a slower pace than before, beginning to grow more than a little tired from all the constant running and walking.
                                You figure the soldiers <span class="bold">must</span> have given up by now.
                                If they even noticed you to begin with, that is.
                                Which you're reasonably sure that they didn't.
                            </div>
                            <div class="text">
                                Overall, you end up enjoying a nice little walk through the forest, 
                                which gives you plenty of time to think a few things through.
                                Your legs are very grateful for the lower tempo you've attained.
                                Like winding down after a stressful workout, you start to feel oddly <span class="italic">satisfied</span>.
                                You've successfully pulled off one of the most exhilarating heists of your life,
                                and you may or may not have put yourself on the path of a miraculous recovery from crippling debt.
                            </div>
                            <div class="text">
                                Just as you were starting to feel wholesomely relaxed,
                                you hear a commotion coming from a small clearing up ahead.
                                At first it sounds like arguing, some kind of heated debate between a woman and a couple of guys.
                                Then, a single, loud, feminine scream for help echoes throughout the forest, 
                                although it appears to be forcibly silenced about halfway through.
                                In place of the debate comes the racket of a struggle.
                            </div>`;

    var contentFromHome = `<div class="text">
                                Your decision to investigate the source of the noise that interrupted your trip home
                                leads you back across the road, and a little ways into the forest.
                                The initial scream is followed by a plethora of panicked shouts for help.
                                Spurred on by the thought of rescuing a damsel in distress, you hastily make your way 
                                through the woods.
                            </div>
                            <div class="text">
                                The shrieks get louder as you approach, until finally the very last one gets cut off about halfway through.
                                Muffled, although you know not by <span class="italic">what</span>.
                                You double your pace, practically sprinting forwards as fast as you can, only to
                                stop dead in your tracks as you become aware of the sounds of a struggle coming from up ahead.
                            </div>`;

    var contentEnd = `      <div class="text">
                                Alarmed, you lower your posture and slowly sneak forwards.
                                Silent like a mouse, you cautiously approach the clearing.
                                Getting closer, you hide behind a young tree, which conveniently has a dense bush right besides it.
                                The shrubbery concealing your body, 
                                you can freely peek out from behind the trunk of the sapling to observe the situation unfolding before you.
                            </div>
                            <div class="text">
                                <a href="scenes/Forest/bandit/arrival/intro-full.png" target="_blank">
                                    <img class="nsfw" src="scenes/Forest/bandit/arrival/intro.png" title="Made by Sneaky">
                                </a>
                            </div>
                            <div class="text">
                                An all-male band of five scantily-dressed kobolds is wrestling an anthromorphic dragoness nearly twice their size, 
                                in what is no doubt a stickup gone wrong.
                                You're not sure how, but they've managed to knock the woman off her legs.
                                She's on her back on the leafy forest floor, visibly struggling to pry the smaller scalies off of her.
                                Her mouth is gagged with what appears to be the ${global.kobold.inventory.createItemWithTooltip(new LoinCloth())} of one of the males, 
                                which explains her sudden silence, as well as the nudity of one of them.
                            </div>
                            <div class="text">
                                Two of the kobolds are trying their hardest to subdue the dragoness' 
                                ${global.kobold.inventory.createItemWithTooltip(new RedDress())}-constrained legs, 
                                the powerful woman's tail wildly flailing about, lashing at them from underneath her frame.
                                The naked one is, together with one of the clothed kobolds, currently straining to keep the woman's arms in check.
                                The fifth and final kobold, who seems to be just a little bit better dressed than his peers, 
                                is pinning the lady's head to the ground with a single hand, 
                                whilst simultaneously keeping the loincloth firmly secured in her muzzle with the other.
                                You figure this dapper one is the ringleader of the bunch.
                            </div>
                            <div class="text">
                                While you don't immediately recognize them, you imagine the group is one of the many gangs that have made this forest their home.
                                That means the woman is probably a traveller or a local out for a stroll in the woods.
                                Maybe she was picking flowers or having a picnic or something when they confronted her and demanded who knows what.
                                She refused, a struggle ensued, and then you arrived to spy on the ordeal.
                                That's what you make of this situation, at least.
                            </div>
                            <div class="text">
                                Just as it seems like the dragoness is about to turn the tide against her assailants, 
                                the most fashionable of the kobolds decides it's time to stop playing around.
                                He pulls a ${global.kobold.inventory.createItemWithTooltip(new SmallKnife())} 
                                out of his ${global.kobold.inventory.createItemWithTooltip(new LinenPants())},
                                and threateningly presses the blade against her exposed, blue-scaled throat.
                            </div>
                            <div class="text">
                                The woman instantly freezes, her protests dying out in the blink of an eye.
                                The hateful glare on her face slowly turns into a shocked, defeated, almost sad expression.
                                The kobolds grin wickedly as the dragoness' limbs stop struggling against their collective grasp, 
                                one of them already letting go of his assigned body part 
                                to slide his hand underneath his own ${global.kobold.inventory.createItemWithTooltip(new KoboldUnderwear())},
                                a clear indication of the group's intentions.
                            </div>`;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the main content of this section.
     * @returns {string} The main content of this section.
     */
    function buildContent() {
        var content;
        var src = ctrl.bandit.getSource();
        if (src === ForestBanditSourceEnum.WOODS) {
            content = contentFromWoods;
        } else {
            content = contentFromHome;
        }
        content += contentEnd;
        return content;
    }

    /**
     * Builds and returns the throw rock choice button.
     */
    function buildRockChoice() {
        var hasRock = ctrl.bandit.arrivalHasRock();
        var disabled = (ctrl.bandit.hasMadeArrivalChoice() || !hasRock) ? "disabled" : "";
        var isSelected = ctrl.bandit.getArrivalChoice() == ForestBanditArrivalChoiceEnum.ROCK;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${rockId}" ${disabled}>Throw rock</button>`;

        var tooltip;
        if (hasRock) {
            tooltip = `You're outnumbered. Throw your rock from the shadows to knock at least one of them out.`;
        } else {
            tooltip = `If you had a rock, you could throw it at them.`;
        }
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 165px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the intervene choice button.
     */
    function buildInterveneChoice() {
        var disabled = ctrl.bandit.hasMadeArrivalChoice() ? "disabled" : "";
        var isSelected = ctrl.bandit.getArrivalChoice() == ForestBanditArrivalChoiceEnum.INTERVENE;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${interveneId}" ${disabled}>Intervene</button>`;

        var tooltip = `You can't let them do this. Step out of the shadows and approach the gang.`;
        var popupContainer = global.ui.makeToolTip(button, tooltip);
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the watch choice button.
     */
    function buildWatchChoice() {
        var disabled = ctrl.bandit.hasMadeArrivalChoice() ? "disabled" : "";
        var isSelected = ctrl.bandit.getArrivalChoice() == ForestBanditArrivalChoiceEnum.WATCH;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${watchId}" ${disabled}>Watch</button>`;

        var tooltip = `It's best not to get involved. Stay hidden and watch.`;
        var popupContainer = global.ui.makeToolTip(button, tooltip);
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You:</div>`;
        choice += buildRockChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildInterveneChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildWatchChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + rockId), $("#" + interveneId), $("#" + watchId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the rock button.
     */
    function registerRockListener() {
        $("#" + rockId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.bandit.makeArrivalChoice(ForestBanditArrivalChoiceEnum.ROCK);
            loadNextPart(toRock);
        });
    }

    /**
     * Adds a listener to the intervene button.
     */
    function registerInterveneListener() {
        $("#" + interveneId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.bandit.intervene.setInterveneSource(ForestBanditInterveneSourceEnum.APPROACH);
            ctrl.bandit.makeArrivalChoice(ForestBanditArrivalChoiceEnum.INTERVENE);
            loadNextPart(toIntervene);
        });
    }

    /**
     * Adds a listener to the watch button.
     */
    function registerWatchListener() {
        $("#" + watchId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.bandit.makeArrivalChoice(ForestBanditArrivalChoiceEnum.WATCH);
            loadNextPart(toWatch);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = "banditArrival";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        var change = "";
        var src = ctrl.bandit.getSource();
        if (src === ForestBanditSourceEnum.WOODS) {
            change = ctrl.bandit.arrivalStatusChange();
        }

        ctrl.bgm.fadeLoop();
        ctrl.bandit.introSound.playSettingsDependent();
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += change;
        part += buildChoice();
        part += `</div>`;
        part += toWatch.build();
        if (ctrl.bandit.getArrivalChoice() === ForestBanditArrivalChoiceEnum.INTERVENE) { // Prevent building twice.
            part += toIntervene.build();
        }
        part += toRock.build();
        part += toReward.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        toWatch.registerListeners();
        toIntervene.registerListeners();
        toRock.registerListeners();
        toReward.registerListeners();

        if (ctrl.bandit.hasMadeArrivalChoice()) {
            return;
        }

        registerRockListener();
        registerInterveneListener();
        registerWatchListener();

    };
}

/**
 * Choices for the arrival of the bandit encounter.
 */
var ForestBanditArrivalChoiceEnum = {
    ROCK: 1,
    INTERVENE: 2,
    WATCH: 3
};

