/**
 * This class acts as a dedicated controller for the woods part of the Forest scene.
 * @param {string} sceneId The id of the scene.
 */
function ForestWoodsController(sceneId) {
    // PRIVATE MEMBERS \\       var private = "test";
    var id = sceneId;
    var arrivalChoiceId = "woodsArrivalChoice";
    var arrivalStatusId = "woodsArrivalStatus";
    var unknownChoiceId = "woodsUnknownChoice";
    var hideChoiceId = "woodsHideChoice";

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    // PUBLIC MEMBERS \\        this.public = "test";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Makes the arrival choice.
     * @param {ForestWoodsArrivalChoiceEnum} choice The choice that was made.
     */
    this.makeArrivalChoice = function (choice) {
        var history = global.kobold.history.get(id);
        history[arrivalChoiceId] = choice;
        global.kobold.history.set(id, history);
    };

    /**
     * Returns whether or not the arrival choice has been made.
     * @returns {boolean} Whether or not the path choice has been made.
     */
    this.hasMadeArrivalChoice = function () {
        return global.kobold.history.has(id, arrivalChoiceId);
    };

    /**
     * Fetches the arrival choice from history and returns it.
     * May return undefined if the choice has not yet been made.
     * @returns {ForestWoodsArrivalChoiceEnum} The choice that was made.
     */
    this.getArrivalChoice = function () {
        var history = global.kobold.history.get(id);
        return history[arrivalChoiceId];
    };
    
    /**
     * Reduces the kobold's stamina if required.
     * @returns {string} HTML describing the change.
     */
    this.arrivalStatusChange = function () {
        if (!global.kobold.history.has(id, arrivalStatusId)) {
            global.kobold.status.stamina.decrease(10, "Long hike");
            var history = global.kobold.history.get(id);
            history[arrivalStatusId] = true;
            global.kobold.history.set(id, history);
        }
        return global.ui.change.buildNotification([
            new Change("Hiking", "Stamina", -10)
        ]);
    };
    
    /**
     * Makes the unknown choice.
     * @param {} choice The choice that was made.
     */
    this.makeUnknownChoice = function (choice) {
        var history = global.kobold.history.get(id);
        history[unknownChoiceId] = choice;
        global.kobold.history.set(id, history);
    };

    /**
     * Returns whether or not the unknown choice has been made.
     * @returns {boolean} Whether or not the path choice has been made.
     */
    this.hasMadeUnknownChoice = function () {
        return global.kobold.history.has(id, unknownChoiceId);
    };

    /**
     * Fetches the unknown choice from history and returns it.
     * May return undefined if the choice has not yet been made.
     * @returns {} The choice that was made.
     */
    this.getUnknownChoice = function () {
        var history = global.kobold.history.get(id);
        return history[unknownChoiceId];
    };
    
    /**
     * Makes the hide choice.
     * @param {} choice The choice that was made.
     */
    this.makeHideChoice = function (choice) {
        var history = global.kobold.history.get(id);
        history[hideChoiceId] = choice;
        global.kobold.history.set(id, history);
    };

    /**
     * Returns whether or not the hide choice has been made.
     * @returns {boolean} Whether or not the path choice has been made.
     */
    this.hasMadeHideChoice = function () {
        return global.kobold.history.has(id, hideChoiceId);
    };

    /**
     * Fetches the hide choice from history and returns it.
     * May return undefined if the choice has not yet been made.
     * @returns {} The choice that was made.
     */
    this.getHideChoice = function () {
        var history = global.kobold.history.get(id);
        return history[hideChoiceId];
    };

}
