/**
 * Fight section of the Underground Cave.
 * @param {UndergroundCaveController} controller The Underground Cave controller.
 */
function UndergroundCaveLetGo(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = UndergroundCaveWrestlingWinChoice.GO;
    var reqController = ctrl.wrestleWin;
    var subController = ctrl.preContinue;
    var changeController = ctrl.letGo;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = new UndergroundCaveLetGoLeave(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            The basilisk is already beaten.
                            There is no point to taking its life.
                            It has submitted to you.
                            You hope it won't turn aggressive once more after you release it,
                            but you don't really want to take its life either.
                        [/p]
                        [p]
                            Despite doubt growing in the back of your mind, you slowly release your grip on the monster's throat.
                            It immediately begins to gasp for air, taking a few deep breaths.
                            At least it doesn't immediately appear hostile.
                            If it wanted to continue fighting, it'd have thrown you off its back by now.
                            You roll off of the beast, and exhaustedly rise to your feet.
                            It looks up at you, submissiveness clear on its face, like a dog that knows it wronged its master.
                            This cave must be its lair or something.
                            It was just trying to protect its territory.
                        [/p]
                        [p]
                            You give the basilisk a short, understanding nod, before gesturing towards the water.
                            You could sure use a drink after a fight like that, and you've no doubt that it, too, is thirsty.
                            The both of you walk towards the water.
                            At its edge, you drop to your hands and knees.
                            Together with the monster you were fighting not a minute ago,
                            you lower your head to the surface of the water,
                            and the both of you start greedily lapping up the fresh, revitalizing liquid.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}
