/**
 * Controller for the Home scene.
 * @param {string} sceneId The id of the scene.
 */
function HomeController(sceneId) {
    // PRIVATE MEMBERS \\       var private = "test";
    var id = sceneId;
    var statusId = "status";
    var genderId = "gender";
    var autoSaveId = "autoSave";
    var goldId = "gold";
    var continueId = "continue";
    var underwearId = "underwear";
    var pantsId = "pants";
    var braId = "bra";
    var shirtId = "shirt";

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    // PUBLIC MEMBERS \\        this.public = "test";
    this.hamletSceneName = "SekiWorkshop";
    this.hamletFolder = "HamletDay2";
    this.saved = new HomeSavedController(id);
    this.unsaved = new HomeUnsavedController(id);

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /*
     * Stores the status of the home at scene-entry time.
     */
    this.status = function () {
        global.kobold.history.setIfNotSet(id, statusId, global.kobold.history.shared.home.status);
        return global.kobold.history.getKey(id, statusId);
    };

    /*
     * Stores the kobold's base gender.
     */
    this.gender = function () {
        global.kobold.history.setIfNotSet(id, genderId, global.kobold.body.getBaseGender());
        return global.kobold.history.getKey(id, genderId);
    };

    /*
     * Autosaves the game if necessary.
     */
    this.autoSave = function () {
        global.kobold.history.doIfNotSet(id, autoSaveId, true, function () {
            global.saveManager.autoSave();
        });
    };


    /**
     * Logs and returns the amount of gold the kobold had at the start of the scene.
     */
    this.gold = function () {
        global.kobold.history.setIfNotSet(id, goldId, global.kobold.inventory.coins);
        return global.kobold.history.getKey(id, goldId);
    };

    /**
     * Signals the scene has been continued.
     */
    this.continue = function () {
        global.kobold.history.setKey(id, continueId, true);
    };

    /**
     * Returns whether or not the scene has continued.
     * @returns {boolean} True if the scene has continued, false otherwise.
     */
    this.hasContinued = function () {
        return global.kobold.history.has(id, continueId);
    };

    this.pants = function () {
        global.kobold.history.setIfNotSet(id, pantsId, global.kobold.inventory.equipment.pants);
        return global.kobold.inventory.equipment.buildGearFromHistory(global.kobold.history.getKey(id, pantsId));
    };

    this.bra = function () {
        global.kobold.history.setIfNotSet(id, braId, global.kobold.inventory.equipment.bra);
        return global.kobold.inventory.equipment.buildGearFromHistory(global.kobold.history.getKey(id, braId));
    };
    
    this.shirt = function () {
        global.kobold.history.setIfNotSet(id, shirtId, global.kobold.inventory.equipment.shirt);
        return global.kobold.inventory.equipment.buildGearFromHistory(global.kobold.history.getKey(id, shirtId));
    };

    this.underwear = function () {
        global.kobold.history.setIfNotSet(id, underwearId, global.kobold.inventory.equipment.underwear);
        return global.kobold.inventory.equipment.buildGearFromHistory(global.kobold.history.getKey(id, underwearId));
    };
    
    this.introAudio =  new AudioController(id, "res/audio/home/tension.mp3", 100);
}

