/**
 * Arrival section of Varanar, Afternoon Three.
 * @param {AfternoonThreeParlorController} controller The Varanar, Afternoon Three controller.
 */
function AfternoonThreeParlorDecline(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = AfternoonThreeParlorEntranceChoice.DECLINE;
    var reqController = false; // Set manually
    var subController = ctrl.secondOffer;
    var changeController = false;

    var firstId = arguments.callee.name + "ButtonOne";
    var secondId = arguments.callee.name + "ButtonTwo";

    var firstNext = ctrl.fragments.secondDecline;
    var secondNext = ctrl.fragments.noGoldAccept;

    var firstChoice = ctrl.secondChoice.DECLINE;
    var secondChoice = ctrl.secondChoice.ACCEPT;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var barterSuccess = global.kobold.history.shared.varanar.dayThree.afternoon.parlorBargainSuccess;
        var barterAttempted = reqController === ctrl.bargain;
        var toReturn = `[p]
                            ${barterSuccess ? `Something is definitely wrong here. No human would offer a discount to a kobold.
                            Then again, he [i]does[/i] rely on your kind for his entire livelihood.
                            ` : barterAttempted ? `If he's not going to give you a discount, then you're not going to have a massage.
                            Simple as that. Plus this entire thing seems a little fishy to you.
                            ` : `Something is definitely wrong here. No human would treat a kobold with this much respect.`}
                            You shake your head no.
                            No deal.
                        [/p]
                        [p]
                            Tychus grumbles loudly, mumbling something you don't understand.
                            "[color=purple]${barterSuccess ? `I give you a discount, and [b]still[/b] you refuse?
                            ` : barterAttempted ? `Is it because I'm not giving you a discount?
                            ` : `Is it because I'm a human?`}
                            How about this.
                            I'll make you an offer.
                            A once-in-a-lifetime deal.
                            You get a [b]freebie[/b].
                            No payment, one massage.
                            You'll be back for more anyway, after you feel how [b]amazing[/b] it can be.
                            What do you say?[/color]"
                        [/p]
                        [p]
                            Wait, what?
                            [b]Really[/b]?
                            For [b]free[/b]?
                            Why?
                            That makes you even [b]more[/b] suspicious.
                            Why does Tychus want you to get a massage so badly?
                            Is he [b]that[/b] desperate for new customers?
                            While you are [b]very[/b] wary about this whole situation,
                            you actually [b]do[/b] kind of want a massage.
                            You are left conflicted.
                            What should you do?
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFirstChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === firstChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${firstId}" ${disabled}>Decline</button>`;

        var tooltip = global.parser.parse(`Something's fishy here. You think it's time for you to leave.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 210px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildSecondChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === secondChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${secondId}" ${disabled}>Accept</button>`;

        var tooltip = global.parser.parse(`Well, if it's free, then you don't see why not!`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 180px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You:</div>`;
        choice += buildFirstChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildSecondChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + firstId), $("#" + secondId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerFirstListener() {
        $("#" + firstId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(firstChoice);
            loadNextPart(firstNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerSecondListener() {
        $("#" + secondId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(secondChoice);
            loadNextPart(secondNext);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        reqController = ctrl.entrance;
        if (reqController.get() === AfternoonThreeParlorEntranceChoice.BARTER) {
            reqController = ctrl.bargain;
        }

        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += firstNext.build();
        part += secondNext.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        firstNext.registerListeners();
        secondNext.registerListeners();

        if (subController.has()) {
            return;
        }

        registerFirstListener();
        registerSecondListener();
    };
}
