/**
 * Run section of Varanar, Afternoon Three.
 * @param {AfternoonThreeParlorController} controller The Varanar, Afternoon Three controller.
 */
function AfternoonThreeParlorDiveFail(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var subController = ctrl.preFail;
    var changeController = false;

    var autoContinue = false;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = ctrl.fragments.bottleFail;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            A jar of oil?
                            You need to dive to the ground at the exact right time if you want to dodge that!
                            He'll never see that coming!
                            Preparing to dive, you continue heading for the door.
                            The human, predictably, hurls the heavy pot your way.
                        [/p]
                        ${global.ui.condFail(`Luck below 7`)}
                        [p]
                            You dive to the floor, your inertia-driven body sliding along the ground,
                            your face harshly [b]smacking[/b] against the wall, knocking you senseless.
                            As if to add insult to injury, the jar painfully impacts against your prone back,
                            cracking open, breaking into a million little pieces, hastening your descent.
                            Your sight goes black.
                        [/p]
                        [p]
                            You wake up a few moments later, still on the floor.
                            Your face hurts, your back hurts, your [i]everything[/i] hurts.
                            Then you realize: you were [b]running[/b].
                            Before you manage to scramble to your feet, Tychus has already caught up to you.
                            The human coarsely [b]grabs[/b] you by your tail,
                            lifting you up off the ground and slinging you over his shoulder like a piece of [b]meat[/b].
                            You try to fight back, but getting hit by the jar has left you dazed and stunned.
                            The most you manage to do is struggle and squirm a little, not nearly enough to free yourself.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        if (autoContinue) {
            subController && subController.continue();
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += (!autoContinue && buildChoice()) || "";
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (!subController || subController.continued()) {
            return;
        }

        registerNextListener();
    };
}
