/**
 * Fail section of Varanar, Afternoon Three.
 * @param {AfternoonThreeParlorController} controller The Varanar, Afternoon Three controller.
 */
function AfternoonThreeParlorFightFailEnd(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = ctrl.preFail;
    var subController = false;
    var changeController = false;

    var autoContinue = true;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = ctrl.fragments.failChoices;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            Tychus carries you past the massaging area, into a dark and shady back room,
                            where he unceremoniously [b]slams[/b] you down ontop of a hard, wooden table.
                            The bald man keeps you pinned with one hand,
                            while using the other to tie your limbs to the legs of the table, employing a length of rope.
                            You clothing is ripped from your body, discarded to the side.
                            Although still somewhat [i]out of it[/i], you are awake enough to realize that you are about to have a [b]very[/b] bad time.
                        [/p]
                        [p]
                            The rage that had befallen the human during your fight seems to have vanished completely.
                            A disconcertingly grim look is plastered across his pale face.
                            He reaches for another whip laying about, this time [i]without[/i] steel tip.
                            "[color=purple]All you had to do was accept the [b]damn[/b] massage.[/color]"
                            You attempt to respond, to perhaps smooth-talk your way out of this situation still,
                            but before you manage to utter even a single word, Tychus cracks his whip,
                            knocking the air out of your lungs by lashing you across the chest!
                        [/p]
                        [p]
                            You let out a coughing, pained grunt.
                            "[color=purple]This could have been so much [b]EASIER[/b]![/color]"
                            Another whiplash, this time smacking your soft and tender belly,
                            making you [b]scream[/b] out in [b]agony[/b].
                            Tears flow from your eyes, dripping to the ground below.
                            "[color=purple]Now you're [b]mine[/b]. And I intend to train you well.[/color]"
                        [/p]
                        [p]
                            That being said, the whipping begins properly.
                            Your weary body withers strike after strike of the grown man's powerful whipping.
                            You lose count somewhere after ten.
                            Your mind shuts down, escaping from the pain.
                            By the end of the brutal disciplinary session, your chest is a bloody mess of lacerations,
                            some stretching all the way from your waist up to your shoulders.
                        [/p]
                        [p]
                            You are thrown in a dark room, which is promptly locked.
                            Hours go by.
                            Then days.
                            You are barely fed.
                            Sometimes, instead of a moldy piece of bread, you get taken to the [i]punishment room[/i] for more whipping, to keep your injuries fresh.
                            For the better part of a month, your existence is a mixture of agony, wishing you were dead and thinking you already are.
                            The worst part is that the human still hasn't told you what he wants from you.
                            Or if he did, you can't remember.
                        [/p]
                        [p]
                            That changes one day, when instead of being whipped again, you are brought to the massaging room.
                            You can barely stand.
                            It's raining outside, but the meagre amount of sunlight beaming in through the window still hurts your eyes,
                            which are now used to pitch-black darkness and nothing more.
                            A big, burly anthro bear is laying atop one of the massage tables.
                            You are given one simple order: work his back.
                        [/p]
                        [p]
                            You don't know how to give a massage.
                            You meekly climb atop the table, and then atop the ursine.
                            You ooze some massage oil onto your palms, and try to rub his back as best you can.
                            Your best is not good enough.
                            The bear is everything but satisfied.
                            After half an hour of wasting his time, he pushes you off and complains about your performance to your [i]master[/i].
                            You fear more whipping, but that is not the case.
                            Instead, the human offers his client a new, special kind of service.
                            A tonguebath.
                            [i]Oh no[/i].
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        if (autoContinue) {
            subController && subController.continue();
        }

        global.ui.applyTheme("hamlet_shop");
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += (!autoContinue && buildChoice()) || "";
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (!subController || subController.continued()) {
            return;
        }

        registerNextListener();
    };
}
