/**
 * Item get section of Varanar, Afternoon Three.
 * @param {AfternoonThreeParlorController} controller The Varanar, Afternoon Three controller.
 */
function AfternoonThreeParlorKillFree(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = ctrl.secondFightChoice.FREE;
    var reqController = ctrl.itemGetFight;
    var subController = ctrl.killFree;
    var changeController = ctrl.killFree;

    var firstId = arguments.callee.name + "ButtonOne";
    var secondId = arguments.callee.name + "ButtonTwo";

    var firstNext = new AfternoonThreeParlorFreeRefuse(ctrl);
    var secondNext = new AfternoonThreeParlorFreeAccept(ctrl);

    var firstChoice = AfternoonThreeParlorKillFreeChoice.REFUSE;
    var secondChoice = AfternoonThreeParlorKillFreeChoice.ACCEPT;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        global.kobold.history.shared.varanar.dayThree.afternoon.parlorFreed = true;
        var toReturn = `[p]
                            After a minute of indulging in the rare feeling of [b]pride[/b],
                            your mind settles down from the adrenaline rush that fueled your vicious attack.
                            You did it!
                            You beat the insane man that tried to enslave you!
                            Now to free your fellow kobolds from his apalling rule.
                        [/p]
                        [p]
                            You walk over to the door leading to the [i]break room[/i],
                            and triumphantly swing it open, drawing the attention of the three slaves inside.
                            "[color=blue]Yes, mast-[/color]" the blue one speaks, realizing you aren't the human halfway through her sentence.
                            "[color=blue]Huh? Who are you? A client?[/color]"
                            The green one looks past you, and notices Tychus laying on the floor.
                        [/p]
                        [p]
                            "[color=green]Master?![/color]"
                            Before even offering you a chance to explain what's going on,
                            he rushes past you, crudely pushing you out of the way to check up on the human.
                            The blue one follows suit, kneeling besides Tychus' body.
                            The red one doesn't seem to care all too much.
                            She casually saunters out of the break room, and casually leans against a wall, observing the display.
                        [/p]
                        [p]
                            "[color=green]Master, [b]no[/b]!
                            You [b]KILLED[/b] him![/color]" the green kobold laments hysterically,
                            his loud crying and plentiful tears stressing his apparent [i]fondness[/i] of Tychus.
                            The blue one tried to soothe him, wrapping an arm around him, pulling him close, letting him cry on her shoulder.
                            "[color=blue]Shhh, Green.
                            It's okay.
                            Everything's going to be fine.
                            Focus on your breathing, okay?
                            Like I taught you.[/color]"
                        [/p]
                        [p]
                            While consoling her peer, Blue shoots daggers at you with her eyes, glaring at you with a hateful look on her face.
                            You [i]did[/i] cause her friend to have a [b]mental breakdown[/b], but you thought you were doing the right thing!
                            You [b]freed[/b] them!
                            Interrupting your guilt-trip, Red taps your shoulder, and whispers to you:
                            "[color=bred]Old bastard finally got what he deserved, huh?
                            Good job.
                            Orange gave you a massage, right?
                            How about I give you some [i]aftercare[/i]?[/color]"
                            You like the sound of that.
                            You like the sound of that [b]a lot[/b].
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFirstChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === firstChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${firstId}" ${disabled}>Refuse</button>`;

        var tooltip = global.parser.parse(`Freeing them is a reward in itself.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 140px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildSecondChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === secondChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${secondId}" ${disabled}>Accept</button>`;

        var tooltip = global.parser.parse(`You could use a little [i]extra[/i], for your troubles.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 160px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You:</div>`;
        choice += buildFirstChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildSecondChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + firstId), $("#" + secondId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerFirstListener() {
        $("#" + firstId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(firstChoice);
            loadNextPart(firstNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerSecondListener() {
        $("#" + secondId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(secondChoice);
            loadNextPart(secondNext);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += firstNext.build();
        part += secondNext.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        firstNext.registerListeners();
        secondNext.registerListeners();

        if (subController.has()) {
            return;
        }

        registerFirstListener();
        registerSecondListener();
    };
}

var AfternoonThreeParlorKillFreeChoice = {
    REFUSE: 1,
    ACCEPT: 2
};
