/**
 * Controller for the Varanar, Afternoon Three scene.
 * @param {string} sceneId The id of the scene.
 * @param {AfternoonThreeParlorController} superCtrl The supercontroller.
 */
function AfternoonThreeRubyController(sceneId, superCtrl) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var id = sceneId;
    SceneController.call(this, id);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    // PUBLIC MEMBERS \\        this.public = "test";
    this.nextSceneReady = superCtrl.nextSceneReady;
    this.nextSceneName = superCtrl.nextSceneName;
    this.nextFolderName = superCtrl.nextSceneName;

    this.misc = superCtrl.misc;

    this.postPantiesMisc = new MiscController(id, "rubyMisc");

    this.scream = new ChangeController(id, "scream", function () {
        global.kobold.status.mental.decrease(2, "Dragoness in trouble");
        global.kobold.inventory.bag.addMisc(new DragonLocket());
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Confusing bump", "Sanity", -1),
            new Change("Public argument", "Sanity", -1),
            new Change("Stolen locket", global.kobold.inventory.createItemWithTooltip(new DragonLocket(), true), +1)
        ]);
    });

    this.screamLeave = new ChangeController(id, "screamLeave", function () {
        global.kobold.status.mental.increase(4, "Free pendant");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Free locket", "Sanity", +8),
            new Change("Dishonorable behavior", "Sanity", -4)
        ]);
    });

    this.screamApproach = new ChangeController(id, "screamApproach", function () {
        global.kobold.status.mental.decrease(3, "Treated poorly");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Treated poorly", "Sanity", -3)
        ]);
    });

    this.approachHandOver = new ChangeController(id, "approachHandOver", function () {
        var t1 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyt1;
        var t2 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyt2;
        var t3 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyt3;
        global.kobold.inventory.bag.removeMisc(new DragonLocket());
        if (t1) {
            global.kobold.status.mental.decrease(6, "Treated poorly");
        } else if (t2) {
            global.kobold.status.mental.increase(3, "Rewarded");
            global.kobold.inventory.coins = global.kobold.inventory.coins + 14;
        } else {
            global.kobold.status.mental.increase(10, "Massive reward");
            global.kobold.inventory.coins = global.kobold.inventory.coins + 96;
        }
    }, function () {
        var t1 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyt1;
        var t2 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyt2;
        var t3 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyt3;
        if (t1) {
            return global.ui.change.buildNotification([
                new Change("Insulted", "Sanity", -3),
                new Change("Berated", "Sanity", -3),
                new Change("Returned locket", global.kobold.inventory.createItemWithTooltip(new DragonLocket(), true), -1)
            ]);
        } else if (t2) {
            return global.ui.change.buildNotification([
                new Change("Personal praise", "Sanity", +4),
                new Change("Kobolds judged", "Sanity", -3),
                new Change("Got rewarded", "Sanity", +2),
                new Change("Returned locket", global.kobold.inventory.createItemWithTooltip(new DragonLocket(), true), -1),
                new Change("Reward", "Gold", +14)
            ]);
        } else {
            return global.ui.change.buildNotification([
                new Change("Bountiful praise", "Sanity", +6),
                new Change("Massive reward", "Sanity", +4),
                new Change("Returned locket", global.kobold.inventory.createItemWithTooltip(new DragonLocket(), true), -1),
                new Change("Reward", "Gold", +96)
            ]);
        }
    });

    this.bargain = new ChoiceController(id, "bargain");

    this.kind = new ChangeController(id, "kind", function () {
        var t1 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyt1;
        var t2 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyt2;
        var t3 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyt3;
        if (t1) {
            global.kobold.status.mental.increase(4, "Bullied dragoness");
        } else if (t2) {
            global.kobold.status.mental.increase(3, "Educated dragoness");
        } else {
            global.kobold.status.mental.increase(2, "Kind dragoness");
        }
    }, function () {
        var t1 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyt1;
        var t2 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyt2;
        var t3 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyt3;
        if (t1) {
            return global.ui.change.buildNotification([
                new Change("Bullied dragoness", "Sanity", +2),
                new Change("Got what you wanted", "Sanity", +2)
            ]);
        } else if (t2) {
            return global.ui.change.buildNotification([
                new Change("Educated dragoness", "Sanity", +1),
                new Change("Got what you wanted", "Sanity", +2)
            ]);
        } else {
            return global.ui.change.buildNotification([
                new Change("Didn't need to ask", "Sanity", +2)
            ]);
        }
    });

    this.kindReturn = new ChangeController(id, "kindReturn", function () {
        var t1 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyt1;
        var t2 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyt2;
        var t3 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyt3;
        global.kobold.inventory.bag.removeMisc(new DragonLocket());
        if (t1) {
            global.kobold.status.mental.increase(2, "Bullied dragoness more");
        } else if (t2) {
            global.kobold.status.mental.increase(3, "Educated dragoness");
        } else {
            global.kobold.status.mental.increase(12, "Hugged dragoness");
        }
    }, function () {
        var t1 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyt1;
        var t2 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyt2;
        var t3 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyt3;
        if (t1) {
            return global.ui.change.buildNotification([
                new Change("Bullied dragoness more", "Sanity", +2),
                new Change("Returned locket", global.kobold.inventory.createItemWithTooltip(new DragonLocket(), true), -1)
            ]);
        } else if (t2) {
            return global.ui.change.buildNotification([
                new Change("Taught her a lesson", "Sanity", +2),
                new Change("Returned locket", global.kobold.inventory.createItemWithTooltip(new DragonLocket(), true), -1)
            ]);
        } else {
            return global.ui.change.buildNotification([
                new Change("Dragoness hug", "Sanity", +12),
                new Change("Returned locket", global.kobold.inventory.createItemWithTooltip(new DragonLocket(), true), -1)
            ]);
        }
    });

    this.kindMore = new ChangeController(id, "kindMore", function () {

    }, function () {
        return global.ui.change.buildNotification([
            new Change("TODO", "CHANGE", +1)
        ]);
    });

    this.kindMoreReturn = new ChangeController(id, "kindMoreReturn", function () {

    }, function () {
        return global.ui.change.buildNotification([
            new Change("TODO", "CHANGE", +1)
        ]);
    });

    this.kindMasturbate = new ChoiceController(id, "kindMasturbate");

    this.kindMasturbateContinue = new ChangeController(id, "kindMasturbateContinue", function () {

    }, function () {
        return global.ui.change.buildNotification([
            new Change("TODO", "CHANGE", +1)
        ]);
    });

    this.kindMasturbateDirty = new ChangeController(id, "kindMasturbateDirty", function () {

    }, function () {
        return global.ui.change.buildNotification([
            new Change("TODO", "CHANGE", +1)
        ]);
    });

    this.kindLateChoices = new ChoiceController(id, "kindLateChoices");

    this.kindLateLeave = new ChangeController(id, "kindLateLeave", function () {

    }, function () {
        return global.ui.change.buildNotification([
            new Change("TODO", "CHANGE", +1)
        ]);
    });

    this.kindLateReturn = new ChangeController(id, "kindLateReturn", function () {

    }, function () {
        return global.ui.change.buildNotification([
            new Change("TODO", "CHANGE", +1)
        ]);
    });

    this.kiss = new ChangeController(id, "kiss", function () {
        var t1 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyt1;
        var t2 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyt2;
        var t3 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyt3;
        if (t1) {
            global.kobold.status.mental.increase(4, "Kissed dragoness");
        } else if (t2) {
            global.kobold.status.mental.increase(8, "Kissed dragoness");
        } else {
            global.kobold.status.mental.increase(12, "Kissed dragoness");
        }
    }, function () {
        var t1 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyt1;
        var t2 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyt2;
        var t3 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyt3;
        if (t1) {
            return global.ui.change.buildNotification([
                new Change("Minor kiss", "Sanity", +4)
            ]);
        } else if (t2) {
            return global.ui.change.buildNotification([
                new Change("Adequate kiss", "Sanity", +8)
            ]);
        } else {
            return global.ui.change.buildNotification([
                new Change("Long-lasting kiss", "Sanity", +12)
            ]);
        }
    });

    this.kissReturn = new ChangeController(id, "kissReturn", function () {
        global.kobold.inventory.bag.removeMisc(new DragonLocket());
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Returned locket", global.kobold.inventory.createItemWithTooltip(new DragonLocket(), true), -1)
        ]);
    });

    this.panties = new ChangeController(id, "panties", function () {
        var t1 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyt1;
        var t2 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyt2;
        var t3 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyt3;
        if (t1) {
            global.kobold.status.mental.increase(2, "Saw dragoness undress");
        } else if (t2) {
            global.kobold.status.mental.increase(4, "Saw dragoness undress");
        } else {
            global.kobold.status.mental.increase(8, "Dragoness flashed groin");
        }
    }, function () {
        var t1 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyt1;
        var t2 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyt2;
        var t3 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyt3;
        if (t1) {
            return global.ui.change.buildNotification([
                new Change("Tense staredown", "Sanity", -2),
                new Change("Glimpse of ass", "Sanity", +2),
                new Change("Got what you wanted", "Sanity", +2)
            ]);
        } else if (t2) {
            return global.ui.change.buildNotification([
                new Change("Glimpse of ass", "Sanity", +2),
                new Change("Got what you wanted", "Sanity", +2)
            ]);
        } else {
            return global.ui.change.buildNotification([
                new Change("Dragoness let you watch", "Sanity", +4),
                new Change("Glimpse of groin", "Sanity", +4)
            ]);
        }
    });

    this.pantiesDiscard = new ChangeController(id, "pantiesDiscard");

    this.pantiesKeep = new ChangeController(id, "pantiesKeep", function () {
        global.kobold.inventory.bag.addMisc(new BlueSilkPantiesMisc());
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Pocketing panties", global.kobold.inventory.createItemWithTooltip(new BlueSilkPantiesMisc(), true), +1)
        ]);
    });

    this.pantiesWear = new ChangeController(id, "pantiesWear", function () {
        global.kobold.inventory.equipment.wear(new BlueSilkPanties());
    }, function () {
        var underwear = that.misc.underwear();
        if (underwear) {
            return global.ui.change.buildNotification([
                new Change("Discarded", global.kobold.inventory.createItemWithTooltip(underwear, true), -1),
                new Change("Wearing panties", global.kobold.inventory.createItemWithTooltip(new BlueSilkPanties(), true), +1)
            ]);
        } else {
            return global.ui.change.buildNotification([
                new Change("Wearing panties", global.kobold.inventory.createItemWithTooltip(new BlueSilkPanties(), true), +1)
            ]);
        }

    });

    this.pantiesCombine = new ChangeController(id, "pantiesCombine", function () {
        global.kobold.inventory.equipment.wear(new TwoCombinedPanties());
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Put on extra panties", global.kobold.inventory.createItemWithTooltip(new TwoCombinedPanties(), true), +1)
        ]);
    });

    this.postpanties = new ChoiceController(id, "postpanties");

    this.postpantiesReturn = new ChangeController(id, "postpantiesReturn", function () {
        var t1 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyt1;
        var t2 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyt2;
        var t3 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyt3;
        global.kobold.inventory.bag.removeMisc(new DragonLocket());
        if (t1) {
            global.kobold.status.mental.increase(3, "Vented frustration");
        } else if (t2) {

        } else {
            global.kobold.status.mental.increase(5, "Seduced by dragoness");
        }
    }, function () {
        var t1 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyt1;
        var t2 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyt2;
        var t3 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyt3;
        if (t1) {
            return global.ui.change.buildNotification([
                new Change("Told the bitch off", "Sanity", +3),
                new Change("Returned locket", global.kobold.inventory.createItemWithTooltip(new DragonLocket(), true), -1)
            ]);
        } else if (t2) {
            return global.ui.change.buildNotification([
                new Change("Returned locket", global.kobold.inventory.createItemWithTooltip(new DragonLocket(), true), -1)
            ]);
        } else {
            return global.ui.change.buildNotification([
                new Change("Seduced by dragoness", "Sanity", +5),
                new Change("Returned locket", global.kobold.inventory.createItemWithTooltip(new DragonLocket(), true), -1)
            ]);
        }
    });

    this.body = new ChangeController(id, "body", function () {
        global.kobold.status.mental.increase(5, "Imminent sex");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Imminent sex", "Sanity", +5)
        ]);
    });

    this.nice = new ChoiceController(id, "nice");

    this.niceCaress = new ChangeController(id, "niceCaress", function () {
        var t1 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyt1;
        var t2 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyt2;
        var t3 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyt3;
        if (t1) {
            global.kobold.status.mental.increase(2, "Groped dragoness");
            global.kobold.status.exertion.increase(3, "Groped dragoness");
        } else if (t2) {
            global.kobold.status.mental.increase(4, "Groped dragoness");
            global.kobold.status.exertion.increase(3, "Groped dragoness");
        } else {
            global.kobold.status.mental.increase(5, "Groped dragoness");
            global.kobold.status.exertion.increase(5, "Groped dragoness");
        }
    }, function () {
        var t1 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyt1;
        var t2 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyt2;
        var t3 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyt3;
        if (t1) {
            return global.ui.change.buildNotification([
                new Change("Groped dragoness", "Sanity", +4),
                new Change("Constant bickering", "Sanity", -2),
                new Change("Groped dragoness", "Sexual exhaustion", +3, true)
            ]);
        } else if (t2) {
            return global.ui.change.buildNotification([
                new Change("Groped dragoness", "Sanity", +4),
                new Change("Groped dragoness", "Sexual exhaustion", +3, true)
            ]);
        } else {
            return global.ui.change.buildNotification([
                new Change("Groped eager dragoness", "Sanity", +6),
                new Change("Infantilism", "Sanity", -1),
                new Change("Groped dragoness", "Sexual exhaustion", +3, true),
                new Change("Sucked her nipples", "Sexual exhaustion", +2, true)
            ]);
        }
    });

    this.niceAsk = new ChangeController(id, "niceAsk", function () {
        var t1 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyt1;
        var t2 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyt2;
        var t3 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyt3;
        if (t1) {
            global.kobold.status.mental.increase(3, "Dragoness striptease");
        } else if (t2) {
            global.kobold.status.mental.increase(4, "Dragoness striptease");
        } else {
            global.kobold.status.mental.increase(5, "Dragoness striptease");
        }
    }, function () {
        var t1 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyt1;
        var t2 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyt2;
        var t3 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyt3;
        if (t1) {
            return global.ui.change.buildNotification([
                new Change("Reluctant striptease", "Sanity", +3)
            ]);
        } else if (t2) {
            return global.ui.change.buildNotification([
                new Change("Striptease", "Sanity", +4)
            ]);
        } else {
            return global.ui.change.buildNotification([
                new Change("Eager striptease", "Sanity", +5)
            ]);
        }
    });

    this.niceForeplay = new ChoiceController(id, "niceForeplay");

    this.niceEatOut = new ChangeController(id, "niceEatOut", function () {
        global.kobold.body.oralVirgin = false;
        var t1 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyt1;
        var t2 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyt2;
        var t3 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyt3;
        if (t1) {
            global.kobold.status.mental.increase(3, "Ate out dragoness");
            global.kobold.status.exertion.increase(6, "Ate out dragoness");
        } else if (t2) {
            global.kobold.status.mental.increase(4, "Ate out dragoness");
            global.kobold.status.exertion.increase(6, "Ate out dragoness");
        } else {
            global.kobold.status.mental.increase(5, "Ate out dragoness");
            global.kobold.status.exertion.increase(6, "Ate out dragoness");
        }
    }, function () {
        var t1 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyt1;
        var t2 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyt2;
        var t3 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyt3;

        if (t1) {
            return global.ui.change.buildNotification([
                new Change("Ate out dragoness", "Sanity", +5),
                new Change("Insults and reluctance", "Sanity", -2),
                new Change("Ate out dragoness", "Sexual exhaustion", +5, true),
                new Change("Touched self", "Sexual exhaustion", +1, true)
            ]);
        } else if (t2) {
            return global.ui.change.buildNotification([
                new Change("Ate out dragoness", "Sanity", +5),
                new Change("Annoying reluctance", "Sanity", -1),
                new Change("Ate out dragoness", "Sexual exhaustion", +5, true),
                new Change("Touched self", "Sexual exhaustion", +1, true)
            ]);
        } else {
            return global.ui.change.buildNotification([
                new Change("Ate out dragoness", "Sanity", +5),
                new Change("Ate out dragoness", "Sexual exhaustion", +5, true),
                new Change("Touched self", "Sexual exhaustion", +1, true)
            ]);
        }
    });

    this.niceGetServiced = new ChangeController(id, "niceGetServiced", function () {
        var t1 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyt1;
        var t2 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyt2;
        var t3 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyt3;
        var dickt4 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyDickt4;
        var dickt3 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyDickt3;
        var dickt2 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyDickt2;
        var dickt1 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyDickt1;
        global.kobold.status.exertion.increase(5, "Serviced by dragoness");

        if (t1) {
            if (dickt4) {
                global.kobold.status.mental.increase(7, "Serviced by dragoness");
            } else if (dickt3) {
                global.kobold.status.mental.increase(5, "Serviced by dragoness");
            } else if (dickt2) {
                global.kobold.status.mental.increase(3, "Serviced by dragoness");
            } else if (dickt1) {
                global.kobold.status.mental.increase(1, "Serviced by dragoness");
            } else {
                global.kobold.status.mental.increase(4, "Serviced by dragoness");
            }
        } else if (t2) {
            if (dickt4) {
                global.kobold.status.mental.increase(8, "Serviced by dragoness");
            } else if (dickt3) {
                global.kobold.status.mental.increase(6, "Serviced by dragoness");
            } else if (dickt2) {
                global.kobold.status.mental.increase(4, "Serviced by dragoness");
            } else if (dickt1) {
                global.kobold.status.mental.increase(2, "Serviced by dragoness");
            } else {
                global.kobold.status.mental.increase(5, "Serviced by dragoness");
            }
        } else {
            if (dickt4) {
                global.kobold.status.mental.increase(9, "Serviced by dragoness");
            } else if (dickt3) {
                global.kobold.status.mental.increase(7, "Serviced by dragoness");
            } else if (dickt2) {
                global.kobold.status.mental.increase(5, "Serviced by dragoness");
            } else if (dickt1) {
                global.kobold.status.mental.increase(3, "Serviced by dragoness");
            } else {
                global.kobold.status.mental.increase(6, "Serviced by dragoness");
            }
        }
    }, function () {
        var t1 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyt1;
        var t2 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyt2;
        var t3 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyt3;
        var dickt4 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyDickt4;
        var dickt3 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyDickt3;
        var dickt2 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyDickt2;
        var dickt1 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyDickt1;

        if (t1) {
            if (dickt4) {
                return global.ui.change.buildNotification([
                    new Change("Dick reluctantly sucked", "Sanity", +4),
                    new Change("Impressive cock", "Sanity", +3),
                    new Change("Member serviced", "Sexual exhaustion", +5, true)
                ]);
            } else if (dickt3) {
                return global.ui.change.buildNotification([
                    new Change("Dick reluctantly sucked", "Sanity", +4),
                    new Change("Surprising cock", "Sanity", +1),
                    new Change("Member serviced", "Sexual exhaustion", +5, true)
                ]);
            } else if (dickt2) {
                return global.ui.change.buildNotification([
                    new Change("Dick reluctantly sucked", "Sanity", +4),
                    new Change("Disappointing cock", "Sanity", -1),
                    new Change("Member serviced", "Sexual exhaustion", +5, true)
                ]);
            } else if (dickt1) {
                return global.ui.change.buildNotification([
                    new Change("Dick reluctantly sucked", "Sanity", +4),
                    new Change("Undersized cock", "Sanity", -3),
                    new Change("Member serviced", "Sexual exhaustion", +5, true)
                ]);
            } else {
                return global.ui.change.buildNotification([
                    new Change("Reluctantly eaten out", "Sanity", +4),
                    new Change("Cunt serviced", "Sexual exhaustion", +5, true)
                ]);
            }
        } else if (t2) {
            if (dickt4) {
                return global.ui.change.buildNotification([
                    new Change("Dick sucked", "Sanity", +5),
                    new Change("Impressive cock", "Sanity", +3),
                    new Change("Member serviced", "Sexual exhaustion", +5, true)
                ]);
            } else if (dickt3) {
                return global.ui.change.buildNotification([
                    new Change("Dick sucked", "Sanity", +5),
                    new Change("Surprising cock", "Sanity", +1),
                    new Change("Member serviced", "Sexual exhaustion", +5, true)
                ]);
            } else if (dickt2) {
                return global.ui.change.buildNotification([
                    new Change("Dick sucked", "Sanity", +5),
                    new Change("Disappointing cock", "Sanity", -1),
                    new Change("Member serviced", "Sexual exhaustion", +5, true)
                ]);
            } else if (dickt1) {
                return global.ui.change.buildNotification([
                    new Change("Dick sucked", "Sanity", +5),
                    new Change("Undersized cock", "Sanity", -3),
                    new Change("Member serviced", "Sexual exhaustion", +5, true)
                ]);
            } else {
                return global.ui.change.buildNotification([
                    new Change("Eaten out", "Sanity", +5),
                    new Change("Cunt serviced", "Sexual exhaustion", +5, true)
                ]);
            }
        } else {
            if (dickt4) {
                return global.ui.change.buildNotification([
                    new Change("Dick eagerly sucked", "Sanity", +6),
                    new Change("Impressive cock", "Sanity", +3),
                    new Change("Member serviced", "Sexual exhaustion", +5, true)
                ]);
            } else if (dickt3) {
                return global.ui.change.buildNotification([
                    new Change("Dick eagerly sucked", "Sanity", +6),
                    new Change("Surprising cock", "Sanity", +1),
                    new Change("Member serviced", "Sexual exhaustion", +5, true)
                ]);
            } else if (dickt2) {
                return global.ui.change.buildNotification([
                    new Change("Dick eagerly sucked", "Sanity", +6),
                    new Change("Disappointing cock", "Sanity", -1),
                    new Change("Member serviced", "Sexual exhaustion", +5, true)
                ]);
            } else if (dickt1) {
                return global.ui.change.buildNotification([
                    new Change("Dick eagerly sucked", "Sanity", +6),
                    new Change("Undersized cock", "Sanity", -3),
                    new Change("Member serviced", "Sexual exhaustion", +5, true)
                ]);
            } else {
                return global.ui.change.buildNotification([
                    new Change("Eagerly eaten out", "Sanity", +6),
                    new Change("Cunt serviced", "Sexual exhaustion", +5, true)
                ]);
            }
        }
    });

    this.nicePreSex = new ChoiceController(id, "nicePreSex");

    this.niceSex = new ChangeController(id, "niceSex", function () {
        var t1 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyt1;
        var t2 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyt2;
        var t3 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyt3;
        var dickt4 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyDickt4;
        var dickt3 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyDickt3;
        var dickt2 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyDickt2;
        var dickt1 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyDickt1;

        if (dickt4 || dickt3 || dickt2 || dickt1) {
            global.kobold.body.dickVirgin = false;
        }

        if (t1) {
            if (dickt4) {
                global.kobold.status.mental.increase(12, "Fucked dragoness");
                global.kobold.status.stamina.decrease(10, "Fucked dragoness");
                global.kobold.status.exertion.increase(20, "Fucked dragoness");
            } else if (dickt3) {
                global.kobold.status.mental.increase(9, "Fucked dragoness");
                global.kobold.status.stamina.decrease(10, "Fucked dragoness");
                global.kobold.status.exertion.increase(20, "Fucked dragoness");
            } else if (dickt2) {
                global.kobold.status.mental.increase(4, "Fucked dragoness");
                global.kobold.status.stamina.decrease(5, "Fucked dragoness");
                global.kobold.status.exertion.increase(15, "Fucked dragoness");
            } else if (dickt1) {
                global.kobold.status.mental.increase(3, "Fucked dragoness");
                global.kobold.status.stamina.decrease(5, "Fucked dragoness");
                global.kobold.status.exertion.increase(15, "Fucked dragoness");
            } else {
                global.kobold.status.mental.increase(6, "Fucked dragoness");
                global.kobold.status.stamina.decrease(10, "Fucked dragoness");
                global.kobold.status.exertion.increase(20, "Fucked dragoness");
            }
        } else if (t2) {
            if (dickt4) {
                global.kobold.status.mental.increase(13, "Fucked dragoness");
                global.kobold.status.stamina.decrease(10, "Fucked dragoness");
                global.kobold.status.exertion.increase(20, "Fucked dragoness");
            } else if (dickt3) {
                global.kobold.status.mental.increase(10, "Fucked dragoness");
                global.kobold.status.stamina.decrease(10, "Fucked dragoness");
                global.kobold.status.exertion.increase(20, "Fucked dragoness");
            } else if (dickt2) {
                global.kobold.status.mental.increase(5, "Fucked dragoness");
                global.kobold.status.stamina.decrease(5, "Fucked dragoness");
                global.kobold.status.exertion.increase(15, "Fucked dragoness");
            } else if (dickt1) {
                global.kobold.status.mental.increase(4, "Fucked dragoness");
                global.kobold.status.stamina.decrease(5, "Fucked dragoness");
                global.kobold.status.exertion.increase(15, "Fucked dragoness");
            } else {
                global.kobold.status.mental.increase(8, "Fucked dragoness");
                global.kobold.status.stamina.decrease(10, "Fucked dragoness");
                global.kobold.status.exertion.increase(20, "Fucked dragoness");
            }
        } else {
            if (dickt4) {
                global.kobold.status.mental.increase(14, "Fucked dragoness");
                global.kobold.status.stamina.decrease(10, "Fucked dragoness");
                global.kobold.status.exertion.increase(20, "Fucked dragoness");
            } else if (dickt3) {
                global.kobold.status.mental.increase(11, "Fucked dragoness");
                global.kobold.status.stamina.decrease(10, "Fucked dragoness");
                global.kobold.status.exertion.increase(20, "Fucked dragoness");
            } else if (dickt2) {
                global.kobold.status.mental.increase(9, "Fucked dragoness");
                global.kobold.status.stamina.decrease(5, "Fucked dragoness");
                global.kobold.status.exertion.increase(15, "Fucked dragoness");
            } else if (dickt1) {
                global.kobold.status.mental.increase(8, "Fucked dragoness");
                global.kobold.status.stamina.decrease(5, "Fucked dragoness");
                global.kobold.status.exertion.increase(15, "Fucked dragoness");
            } else {
                global.kobold.status.mental.increase(11, "Fucked dragoness");
                global.kobold.status.stamina.decrease(10, "Fucked dragoness");
                global.kobold.status.exertion.increase(20, "Fucked dragoness");
            }
        }
    }, function () {
        var t1 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyt1;
        var t2 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyt2;
        var t3 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyt3;
        var dickt4 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyDickt4;
        var dickt3 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyDickt3;
        var dickt2 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyDickt2;
        var dickt1 = global.kobold.history.shared.varanar.dayThree.afternoon.rubyDickt1;

        if (t1) {
            if (dickt4) {
                return global.ui.change.buildNotification([
                    new Change("Fucked unwilling dragoness", "Sanity", +6),
                    new Change("Stretched her out", "Sanity", +3),
                    new Change("Made her cum", "Sanity", +3),
                    new Change("Exhausting pounding", "Stamina", -10),
                    new Change("Intensive sex", "Sexual exhaustion", +15, true),
                    new Change("Reached climax", "Sexual exhaustion", +5, true)
                ]);
            } else if (dickt3) {
                return global.ui.change.buildNotification([
                    new Change("Fucked unwilling dragoness", "Sanity", +6),
                    new Change("Made her cum", "Sanity", +3),
                    new Change("Exhausting pounding", "Stamina", -10),
                    new Change("Intensive sex", "Sexual exhaustion", +15, true),
                    new Change("Reached climax", "Sexual exhaustion", +5, true)
                ]);
            } else if (dickt2) {
                return global.ui.change.buildNotification([
                    new Change("Fucked unwilling dragoness", "Sanity", +6),
                    new Change("Almost made her cum", "Sanity", +1),
                    new Change("Interrupted orgasm", "Sanity", -3),
                    new Change("Meagre pounding", "Stamina", -5),
                    new Change("Short-lived sex", "Sexual exhaustion", +10, true),
                    new Change("Reached climax", "Sexual exhaustion", +5, true)
                ]);
            } else if (dickt1) {
                return global.ui.change.buildNotification([
                    new Change("Fucked unwilling dragoness", "Sanity", +6),
                    new Change("Interrupted orgasm", "Sanity", -3),
                    new Change("Meagre pounding", "Stamina", -5),
                    new Change("Short-lived sex", "Sexual exhaustion", +10, true),
                    new Change("Reached climax", "Sexual exhaustion", +5, true)
                ]);
            } else {
                return global.ui.change.buildNotification([
                    new Change("Fucked unwilling dragoness", "Sanity", +6),
                    new Change("Exhausting scissoring", "Stamina", -10),
                    new Change("Intensive sex", "Sexual exhaustion", +15, true),
                    new Change("Reached climax", "Sexual exhaustion", +5, true)
                ]);
            }
        } else if (t2) {
            if (dickt4) {
                return global.ui.change.buildNotification([
                    new Change("Fucked reluctant dragoness", "Sanity", +7),
                    new Change("Stretched her out", "Sanity", +3),
                    new Change("Made her cum", "Sanity", +3),
                    new Change("Exhausting pounding", "Stamina", -10),
                    new Change("Intensive sex", "Sexual exhaustion", +15, true),
                    new Change("Reached climax", "Sexual exhaustion", +5, true)
                ]);
            } else if (dickt3) {
                return global.ui.change.buildNotification([
                    new Change("Fucked reluctant dragoness", "Sanity", +7),
                    new Change("Made her cum", "Sanity", +3),
                    new Change("Exhausting pounding", "Stamina", -10),
                    new Change("Intensive sex", "Sexual exhaustion", +15, true),
                    new Change("Reached climax", "Sexual exhaustion", +5, true)
                ]);
            } else if (dickt2) {
                return global.ui.change.buildNotification([
                    new Change("Fucked reluctant dragoness", "Sanity", +7),
                    new Change("Almost made her cum", "Sanity", +1),
                    new Change("Interrupted orgasm", "Sanity", -3),
                    new Change("Meagre pounding", "Stamina", -5),
                    new Change("Short-lived sex", "Sexual exhaustion", +10, true),
                    new Change("Reached climax", "Sexual exhaustion", +5, true)
                ]);
            } else if (dickt1) {
                return global.ui.change.buildNotification([
                    new Change("Fucked reluctant dragoness", "Sanity", +7),
                    new Change("Interrupted orgasm", "Sanity", -3),
                    new Change("Meagre pounding", "Stamina", -5),
                    new Change("Short-lived sex", "Sexual exhaustion", +10, true),
                    new Change("Reached climax", "Sexual exhaustion", +5, true)
                ]);
            } else {
                return global.ui.change.buildNotification([
                    new Change("Fucked reluctant dragoness", "Sanity", +7),
                    new Change("Almost made her cum", "Sanity", +1),
                    new Change("Exhausting scissoring", "Stamina", -10),
                    new Change("Intensive sex", "Sexual exhaustion", +15, true),
                    new Change("Reached climax", "Sexual exhaustion", +5, true)
                ]);
            }
        } else {
            if (dickt4) {
                return global.ui.change.buildNotification([
                    new Change("Fucked eager dragoness", "Sanity", +8),
                    new Change("Stretched her out", "Sanity", +3),
                    new Change("Made her cum", "Sanity", +3),
                    new Change("Exhausting pounding", "Stamina", -10),
                    new Change("Intensive sex", "Sexual exhaustion", +15, true),
                    new Change("Reached climax", "Sexual exhaustion", +5, true)
                ]);
            } else if (dickt3) {
                return global.ui.change.buildNotification([
                    new Change("Fucked eager dragoness", "Sanity", +8),
                    new Change("Made her cum", "Sanity", +3),
                    new Change("Exhausting pounding", "Stamina", -10),
                    new Change("Intensive sex", "Sexual exhaustion", +15, true),
                    new Change("Reached climax", "Sexual exhaustion", +5, true)
                ]);
            } else if (dickt2) {
                return global.ui.change.buildNotification([
                    new Change("Fucked eager dragoness", "Sanity", +8),
                    new Change("Almost made her cum", "Sanity", +1),
                    new Change("Meagre pounding", "Stamina", -5),
                    new Change("Short-lived sex", "Sexual exhaustion", +10, true),
                    new Change("Reached climax", "Sexual exhaustion", +5, true)
                ]);
            } else if (dickt1) {
                return global.ui.change.buildNotification([
                    new Change("Fucked eager dragoness", "Sanity", +8),
                    new Change("Meagre pounding", "Stamina", -5),
                    new Change("Short-lived sex", "Sexual exhaustion", +10, true),
                    new Change("Reached climax", "Sexual exhaustion", +5, true)
                ]);
            } else {
                return global.ui.change.buildNotification([
                    new Change("Fucked eager dragoness", "Sanity", +8),
                    new Change("Made her cum", "Sanity", +3),
                    new Change("Exhausting scissoring", "Stamina", -10),
                    new Change("Intensive sex", "Sexual exhaustion", +15, true),
                    new Change("Reached climax", "Sexual exhaustion", +5, true)
                ]);
            }
        }
    });

    this.niceReturn = new ChangeController(id, "niceReturn", function () {
        global.kobold.inventory.bag.removeMisc(new DragonLocket());
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Returned locket", global.kobold.inventory.createItemWithTooltip(new DragonLocket(), true), -1)
        ]);
    });
    this.niceDoNot = new ChangeController(id, "niceDoNot", function () {

    }, function () {
        return global.ui.change.buildNotification([
            new Change("TODO", "CHANGE", +1)
        ]);
    });

    this.mean = new ChoiceController(id, "mean");
    this.meanUndress = new ChoiceController(id, "meanUndress");
    this.meanForeplay = new ChoiceController(id, "meanForeplay");
    this.meanPreSex = new ChoiceController(id, "meanPreSex");
    this.meanSex = new ChangeController(id, "meanSex", function () {

    }, function () {
        return global.ui.change.buildNotification([
            new Change("TODO", "CHANGE", +1)
        ]);
    });
    this.meanReturn = new ChangeController(id, "meanReturn", function () {

    }, function () {
        return global.ui.change.buildNotification([
            new Change("TODO", "CHANGE", +1)
        ]);
    });
    this.meanDoNot = new ChangeController(id, "meanDoNot", function () {

    }, function () {
        return global.ui.change.buildNotification([
            new Change("TODO", "CHANGE", +1)
        ]);
    });


    /**this.secondChoice = {
     DECLINE: 1,
     ACCEPT: 2
     };*/

    this.fragments = {};
    this.fragments.kindLateChoices = new AfternoonThreeRubyKindLateChoices(this);
    this.fragments.postPanties = new AfternoonThreeRubyPantiesPostChoices(this);
    this.fragments.niceSex = new AfternoonThreeRubyNiceSex(this);
    this.fragments.niceForeplay = new AfternoonThreeRubyNiceForeplay(this);
    this.fragments.meanSex = new AfternoonThreeRubyMeanSex(this);
    this.fragments.meanForeplay = new AfternoonThreeRubyMeanForeplay(this);
    this.fragments.meanUndress = new AfternoonThreeRubyMeanUndress(this);

    //this.bgm = new AudioController(id, "res/audio/varanar/massageparlor.mp3", 120);

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};
}
