/**
 * Invited section of Varanar, Noon Three.
 * @param {VaranarSoupKitchenController} controller The Varanar, Noon Three controller.
 */
function VaranarSoupKitchenTruthFail(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var subController = ctrl.preContinue;
    var changeController = ctrl.truthFail;

    var autoContinue = false;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = ctrl.fragments.apple;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var name = ctrl.misc.name();
        var paid = global.kobold.history.shared.debtCollector.paid;
        var toReturn = `[p]
                            You tell the man the truth.
                            You're ${paid ? `heavily` : ``} indebted to the Three-Tailed Rat Clan, and are trying to save up some money to pay them off.
                            You [i]could[/i] use your gold to buy food for yourself,
                            but you don't [b]dare[/b] think of the consequences should the clan catch you empty-handed.
                            Worse yet, if one of them finds you spending coins that should belong to [b]them[/b], they'd probably [b]torture[/b] you to death for that.
                            So, here you are, hoping for some food that [i]won't[/i] lead to your slow and painful [b]death[/b].
                        [/p]
                        [p]
                            "[color=ppink]Hmph.
                            I've heard many a [i]kuhbold[/i] claim tah be hounded by this [i]gang[/i].
                            [b]Lying.[/b]
                            That's one thing yer kind is good at, isn't it?
                            How do I know you're not tellin' meh a lie?
                            If you're carryin' that gold around for, surely you know exactly [b]who[/b] it is you owe money to, right?
                            Well then, who is the leader of this so-called [i]Three-Tailed Rat Clan[/i]?[/color]"
                        [/p]
                        ${global.ui.condFail(`Intelligence below 6`)}
                        [p]
                            Uh-oh.
                            That's a tough question.
                            The leader of the Three-Tailed Rat Clan?
                            Come on, ${name}, you know this one.
                            Uhhh, it starts with a [b]T[/b], you think.
                            Or maybe an [b]R[/b]?
                            You honestly can't remember.
                            What the hell was his name?!
                            Wait, do you even know his name?
                        [/p]
                        [p]
                            Unable to respond to the caprine's question, you begin to stammer out a bunch of stalling gibberish.
                            A trick he instantly sees through.
                            "[color=ppink]Hah.
                            You're a bad liar, [i]kuhbold[/i].
                            Come now, we don't serve liars here.
                            Git.
                            Out the door.
                            Or do I need tah [b]throw[/b] yeh out?[/color]"
                        [/p]
                        [p]
                            No.
                            [b]No![/b]
                            You're telling the truth!
                            You [b]swear[/b] you are!
                            You aren't lying, really!
                            "[color=ppink]Yeah right.
                            And me wife, Armok rest'er soul, was a faithful woman, too?
                            Do ye expect me tah believe everythin' without questionin', lizard?
                            Yer a dirty, no-good liar.
                            Now get out of mah soup kitchen.
                            We're [b]closed[/b].
                            [b]Forever[/b].[/color]"
                        [/p]
                        [p]
                            That being said, the fat sheep points towards the door.
                            You wordlessly beg him to let you stay.
                            He looks like he's made his choice.
                            You try to come up with something, [b]anything[/b] to say, but it's hopeless.
                            Your stupidity and your inability to remember a simple detail have cost you a valuable opportunity.
                            Hanging your head, you walk out the door, back towards the market square.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        if (autoContinue) {
            subController.continue();
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += (!autoContinue && buildChoice()) || "";
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}
